==> kubernetes-model-1.0.68-sources.jar: io/fabric8/openshift/api/model/ImageStreamImportFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.Valid;
import java.lang.Object;

public class ImageStreamImportFluentImpl<A extends ImageStreamImportFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ImageStreamImportFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private ImageStreamImportSpecBuilder spec;
    private ImageStreamImportStatusBuilder status;

    public ImageStreamImportFluentImpl(){
    }
    public ImageStreamImportFluentImpl(ImageStreamImport instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public ImageStreamImportFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ImageStreamImportFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ImageStreamImportFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ImageStreamImportFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ImageStreamImportFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 */
@Deprecated public ImageStreamImportSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public ImageStreamImportSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ImageStreamImportSpec spec){
            _visitables.remove(this.spec);
            if (spec!=null){ this.spec= new ImageStreamImportSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public ImageStreamImportFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public ImageStreamImportFluent.SpecNested<A> withNewSpecLike(ImageStreamImportSpec item){
            return new SpecNestedImpl(item);
    }

    public ImageStreamImportFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public ImageStreamImportFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new ImageStreamImportSpecBuilder().build());
    }

    public ImageStreamImportFluent.SpecNested<A> editOrNewSpecLike(ImageStreamImportSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 */
@Deprecated public ImageStreamImportStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public ImageStreamImportStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(ImageStreamImportStatus status){
            _visitables.remove(this.status);
            if (status!=null){ this.status= new ImageStreamImportStatusBuilder(status); _visitables.add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public ImageStreamImportFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public ImageStreamImportFluent.StatusNested<A> withNewStatusLike(ImageStreamImportStatus item){
            return new StatusNestedImpl(item);
    }

    public ImageStreamImportFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public ImageStreamImportFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new ImageStreamImportStatusBuilder().build());
    }

    public ImageStreamImportFluent.StatusNested<A> editOrNewStatusLike(ImageStreamImportStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ImageStreamImportFluentImpl that = (ImageStreamImportFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ImageStreamImportFluent.MetadataNested<N>> implements ImageStreamImportFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ImageStreamImportFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends ImageStreamImportSpecFluentImpl<ImageStreamImportFluent.SpecNested<N>> implements ImageStreamImportFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ImageStreamImportSpecBuilder builder;
    
            SpecNestedImpl(ImageStreamImportSpec item){
                    this.builder = new ImageStreamImportSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new ImageStreamImportSpecBuilder(this);
            }
    
    public N and(){
            return (N) ImageStreamImportFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends ImageStreamImportStatusFluentImpl<ImageStreamImportFluent.StatusNested<N>> implements ImageStreamImportFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ImageStreamImportStatusBuilder builder;
    
            StatusNestedImpl(ImageStreamImportStatus item){
                    this.builder = new ImageStreamImportStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new ImageStreamImportStatusBuilder(this);
            }
    
    public N and(){
            return (N) ImageStreamImportFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}

==> kubernetes-model-4.2.1-sources.jar: io/fabric8/openshift/api/model/ImageStreamImportFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import javax.validation.Valid;
import java.lang.Object;

public class ImageStreamImportFluentImpl<A extends ImageStreamImportFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ImageStreamImportFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private ImageStreamImportSpecBuilder spec;
    private ImageStreamImportStatusBuilder status;

    public ImageStreamImportFluentImpl(){
    }
    public ImageStreamImportFluentImpl(ImageStreamImport instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public ImageStreamImportFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ImageStreamImportFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ImageStreamImportFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ImageStreamImportFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ImageStreamImportFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ImageStreamImportSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public ImageStreamImportSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ImageStreamImportSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new ImageStreamImportSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public ImageStreamImportFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public ImageStreamImportFluent.SpecNested<A> withNewSpecLike(ImageStreamImportSpec item){
            return new SpecNestedImpl(item);
    }

    public ImageStreamImportFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public ImageStreamImportFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new ImageStreamImportSpecBuilder().build());
    }

    public ImageStreamImportFluent.SpecNested<A> editOrNewSpecLike(ImageStreamImportSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public ImageStreamImportStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public ImageStreamImportStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(ImageStreamImportStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new ImageStreamImportStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public ImageStreamImportFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public ImageStreamImportFluent.StatusNested<A> withNewStatusLike(ImageStreamImportStatus item){
            return new StatusNestedImpl(item);
    }

    public ImageStreamImportFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public ImageStreamImportFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new ImageStreamImportStatusBuilder().build());
    }

    public ImageStreamImportFluent.StatusNested<A> editOrNewStatusLike(ImageStreamImportStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ImageStreamImportFluentImpl that = (ImageStreamImportFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ImageStreamImportFluent.MetadataNested<N>> implements ImageStreamImportFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ImageStreamImportFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends ImageStreamImportSpecFluentImpl<ImageStreamImportFluent.SpecNested<N>> implements ImageStreamImportFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ImageStreamImportSpecBuilder builder;
    
            SpecNestedImpl(ImageStreamImportSpec item){
                    this.builder = new ImageStreamImportSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new ImageStreamImportSpecBuilder(this);
            }
    
    public N and(){
            return (N) ImageStreamImportFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends ImageStreamImportStatusFluentImpl<ImageStreamImportFluent.StatusNested<N>> implements ImageStreamImportFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ImageStreamImportStatusBuilder builder;
    
            StatusNestedImpl(ImageStreamImportStatus item){
                    this.builder = new ImageStreamImportStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new ImageStreamImportStatusBuilder(this);
            }
    
    public N and(){
            return (N) ImageStreamImportFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
